window.Gleam.initSearch([{"doc":"outil","title":"outil","content":"# outil\n\n[![Package Version](https://img.shields.io/hexpm/v/outil)](https://hex.pm/packages/outil)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/outil/)\n\nA library for writing command line tools. Like so:\n\n```gleam\nimport gleam/erlang\nimport gleam/io\nimport gleam/list\nimport outil.{command}\nimport outil/arg\nimport outil/opt\n\nfn say_hello() {\n  use cmd &lt;- command(&quot;hello&quot;, &quot;Say hello to someone&quot;)\n  use name, cmd &lt;- arg.string(cmd, &quot;name&quot;)\n  use enthusiasm, cmd &lt;- opt.int(cmd, &quot;enthusiasm&quot;, &quot;How enthusiastic?&quot;, 1)\n\n  outil.implement(\n    cmd,\n    fn(argv) {\n      try name = name(argv)\n      try enthusiasm = enthusiasm(argv)\n\n      let message = &quot;Hello, &quot; &lt;&gt; name &lt;&gt; string.repeat(&quot;!&quot;, enthusiasm)\n\n      Ok(io.println(message))\n    },\n  )\n}\n\nfn main() {\n  // Erlang is not required, this example just uses it for getting ARGV\n  let cmd_args = erlang.start_arguments() |&gt; list.drop(1)\n  outil.execute(say_hello(), cmd_args)\n}\n```\n\nIf you don&#39;t fancy this style of programming, check out [glint] or [Awesome Gleam] for alternatives.\n\n[glint]: https://github.com/tanklesxl/glint\n[Awesome Gleam]: https://github.com/gleam-lang/awesome-gleam#cli\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add outil\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/outil&gt;.\n\n## Roadmap\n\n* Automatic implementation of `--help/-h` option.\n* Automatic printing of usage on `outil` command errors?\n","url":"index.html"},{"doc":"outil/core","title":"Argument","content":"pub type Argument {\n  BoolArgument(name: String)\n  FloatArgument(name: String)\n  IntArgument(name: String)\n  StringArgument(name: String)\n}\n A positional command line argument.\nBoolArgument(name: String)\n\n\nFloatArgument(name: String)\n\n\nIntArgument(name: String)\n\n\nStringArgument(name: String)\n\n\nSynonyms:\noutil/core.Argument\noutil/core Argument","url":"outil/core.html#Argument"},{"doc":"outil/core","title":"ArgvFunction","content":"pub type ArgvFunction(a) =\n  fn(List(String)) -&gt; Result(a, Error)\n A function from the argument vector to a result.\n\nSynonyms:\noutil/core.ArgvFunction\noutil/core ArgvFunction","url":"outil/core.html#ArgvFunction"},{"doc":"outil/core","title":"Command","content":"pub type Command(a) {\n  Command(\n    name: String,\n    description: String,\n    arguments: List(Argument),\n    options: List(Opt),\n    run: fn(List(String)) -&gt; Result(a, Error),\n  )\n}\n A command line interface to a run function.\nCommand(\n  name: String,\n  description: String,\n  arguments: List(Argument),\n  options: List(Opt),\n  run: fn(List(String)) -&gt; Result(a, Error),\n)\n\n\nSynonyms:\noutil/core.Command\noutil/core Command","url":"outil/core.html#Command"},{"doc":"outil/core","title":"Error","content":"pub type Error {\n  MalformedArgument(String, String)\n  MissingArgument(String)\n  NotImplemented(String)\n  OutOfPlaceOption(String)\n}\n Errors that can occur when parsing command line arguments.\nMalformedArgument(String, String)\n\n\nMissingArgument(String)\n\n\nNotImplemented(String)\n\n\nOutOfPlaceOption(String)\n\n\nSynonyms:\noutil/core.Error\noutil/core Error","url":"outil/core.html#Error"},{"doc":"outil/core","title":"Opt","content":"pub type Opt {\n  Opt(\n    long: String,\n    short: Option(String),\n    description: String,\n    value: OptValue,\n  )\n}\n A command line option/flag.\nOpt(\n  long: String,\n  short: Option(String),\n  description: String,\n  value: OptValue,\n)\n\n\nSynonyms:\noutil/core.Opt\noutil/core Opt","url":"outil/core.html#Opt"},{"doc":"outil/core","title":"OptValue","content":"pub type OptValue {\n  BoolOpt\n  FloatOpt(default: Float)\n  IntOpt(default: Int)\n  StringOpt(default: String)\n}\n The type and default value of an option.\nBoolOpt\n\n\nFloatOpt(default: Float)\n\n\nIntOpt(default: Int)\n\n\nStringOpt(default: String)\n\n\nSynonyms:\noutil/core.OptValue\noutil/core OptValue","url":"outil/core.html#OptValue"},{"doc":"outil/core","title":"WithArgument","content":"pub type WithArgument(a, b) =\n  fn(ArgvFunction(a), Command(b)) -&gt; Command(b)\n The type of continuation functions in building a command.\n\nSynonyms:\noutil/core.WithArgument\noutil/core WithArgument","url":"outil/core.html#WithArgument"},{"doc":"outil/core","title":"parse_bool","content":"pub fn parse_bool(arg: String) -&gt; Result(Bool, Nil)\n Parse a Bool from a string.\nSynonyms:\noutil/core.parse_bool\noutil/core parse_bool","url":"outil/core.html#parse_bool"},{"doc":"outil/core","title":"outil/core","content":"","url":"outil/core.html"},{"doc":"outil/opt","title":"bool","content":"pub fn bool(cmd: Command(a), long: String, description: String, continue: fn(\n    fn(List(String)) -&gt; Result(Bool, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a named bool option to the command before continuing.\nSynonyms:\noutil/opt.bool\noutil/opt bool","url":"outil/opt.html#bool"},{"doc":"outil/opt","title":"bool_","content":"pub fn bool_(cmd: Command(a), long: String, short: Option(String), description: String, continue: fn(\n    fn(List(String)) -&gt; Result(Bool, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a bool option with a short name to the command before continuing.\nSynonyms:\noutil/opt.bool_\noutil/opt bool_","url":"outil/opt.html#bool_"},{"doc":"outil/opt","title":"float","content":"pub fn float(cmd: Command(a), long: String, description: String, default: Float, continue: fn(\n    fn(List(String)) -&gt; Result(Float, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a named float option to the command before continuing.\nSynonyms:\noutil/opt.float\noutil/opt float","url":"outil/opt.html#float"},{"doc":"outil/opt","title":"float_","content":"pub fn float_(cmd: Command(a), long: String, short: Option(String), description: String, default: Float, continue: fn(\n    fn(List(String)) -&gt; Result(Float, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a float option with a short name to the command before continuing.\nSynonyms:\noutil/opt.float_\noutil/opt float_","url":"outil/opt.html#float_"},{"doc":"outil/opt","title":"int","content":"pub fn int(cmd: Command(a), long: String, description: String, default: Int, continue: fn(\n    fn(List(String)) -&gt; Result(Int, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a named int option to the command before continuing.\nSynonyms:\noutil/opt.int\noutil/opt int","url":"outil/opt.html#int"},{"doc":"outil/opt","title":"int_","content":"pub fn int_(cmd: Command(a), long: String, short: Option(String), description: String, default: Int, continue: fn(\n    fn(List(String)) -&gt; Result(Int, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add an int option with a short name to the command before continuing.\nSynonyms:\noutil/opt.int_\noutil/opt int_","url":"outil/opt.html#int_"},{"doc":"outil/opt","title":"named_opt_parser","content":"pub fn named_opt_parser(long: String, short: Option(String), parser: fn(\n    String,\n  ) -&gt; Result(a, Nil), default: a) -&gt; fn(List(String)) -&gt;\n  Result(a, Error)\n\nSynonyms:\noutil/opt.named_opt_parser\noutil/opt named_opt_parser","url":"outil/opt.html#named_opt_parser"},{"doc":"outil/opt","title":"string","content":"pub fn string(cmd: Command(a), long: String, description: String, default: String, continue: fn(\n    fn(List(String)) -&gt; Result(String, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a named string option to the command before continuing.\nSynonyms:\noutil/opt.string\noutil/opt string","url":"outil/opt.html#string"},{"doc":"outil/opt","title":"string_","content":"pub fn string_(cmd: Command(a), long: String, short: Option(\n    String,\n  ), description: String, default: String, continue: fn(\n    fn(List(String)) -&gt; Result(String, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a string option with a short name to the command before continuing.\nSynonyms:\noutil/opt.string_\noutil/opt string_","url":"outil/opt.html#string_"},{"doc":"outil/opt","title":"with_named_option","content":"pub fn with_named_option(cmd: Command(a), opt: Opt, default: b, parse: fn(\n    String,\n  ) -&gt; Result(b, Nil), continue: fn(\n    fn(List(String)) -&gt; Result(b, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a named option to the command. Bring your own parser.\n\n The continuation function gets a parser for the option and the command\n with the option added, for further configuration.\nSynonyms:\noutil/opt.with_named_option\noutil/opt with_named_option","url":"outil/opt.html#with_named_option"},{"doc":"outil/opt","title":"outil/opt","content":"","url":"outil/opt.html"},{"doc":"outil/arg","title":"bool","content":"pub fn bool(cmd: Command(a), name: String, continue: fn(\n    fn(List(String)) -&gt; Result(Bool, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a positional bool argument to the command before continuing.\nSynonyms:\noutil/arg.bool\noutil/arg bool","url":"outil/arg.html#bool"},{"doc":"outil/arg","title":"float","content":"pub fn float(cmd: Command(a), name: String, continue: fn(\n    fn(List(String)) -&gt; Result(Float, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a positional float argument to the command before continuing.\nSynonyms:\noutil/arg.float\noutil/arg float","url":"outil/arg.html#float"},{"doc":"outil/arg","title":"int","content":"pub fn int(cmd: Command(a), name: String, continue: fn(\n    fn(List(String)) -&gt; Result(Int, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a positional int argument to the command before continuing.\nSynonyms:\noutil/arg.int\noutil/arg int","url":"outil/arg.html#int"},{"doc":"outil/arg","title":"string","content":"pub fn string(cmd: Command(a), name: String, continue: fn(\n    fn(List(String)) -&gt; Result(String, Error),\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Add a positional string argument to the command before continuing.\nSynonyms:\noutil/arg.string\noutil/arg string","url":"outil/arg.html#string"},{"doc":"outil/arg","title":"outil/arg","content":"","url":"outil/arg.html"},{"doc":"outil","title":"command","content":"pub fn command(name: String, description: String, continue: fn(\n    Command(a),\n  ) -&gt; Command(a)) -&gt; Command(a)\n Create a command with the given name and description, and pass it to the\n given continuation function for further configuration.\n\n The command gets a default implementation that returns an error.\nSynonyms:\noutil.command\noutil command","url":"outil.html#command"},{"doc":"outil","title":"execute","content":"pub fn execute(cmd: Command(a), args: List(String)) -&gt; Result(\n  a,\n  Error,\n)\n Execute the command with the given argument vector, without the program name.\nSynonyms:\noutil.execute\noutil execute","url":"outil.html#execute"},{"doc":"outil","title":"implement","content":"pub fn implement(cmd: Command(a), run: fn(List(String)) -&gt;\n    Result(a, Error)) -&gt; Command(a)\n Add the code to evaluate when the command is executed.\nSynonyms:\noutil.implement\noutil implement","url":"outil.html#implement"},{"doc":"outil","title":"usage","content":"pub fn usage(cmd: Command(a)) -&gt; String\n Return a string describing the usage of the given command.\nSynonyms:\noutil.usage\noutil usage","url":"outil.html#usage"},{"doc":"outil","title":"outil","content":"","url":"outil.html"}]);